@@ -4,10 +4,9 @@ use strict;
 use warnings;
 
 use Tickit;
+use Tickit::Widgets qw( Border Button VBox );
 
-use Tickit::Widgets qw( Box Button VBox );
-
-my $box = Tickit::Widget::Box->new(
+my $border = Tickit::Widget::Border->new(
    h_border => 10,
    v_border => 4,
    child => my $vbox = Tickit::Widget::VBox->new( spacing => 2, bg => "black" ),
@@ -17,12 +16,12 @@ foreach my $colour (qw( red blue green yellow )) {
    $vbox->add(
       Tickit::Widget::Button->new(
          label => $colour,
-         on_click => sub { $box->pen->chattr( bg => $colour ) },
+         on_click => sub { $border->pen->chattr( bg => $colour ) },
       )
    );
 }
 
-my $tickit = Tickit->new( root => $box );
+my $tickit = Tickit->new( root => $border );
 
 $vbox->add(
    Tickit::Widget::Button->new(
